/*
  configdialog.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of wpa_setting.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "wpa_setting.h"
#include "configdialog.h"
#include <qlayout.h>
#include <qhbox.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qlineedit.h>
#include <qgrid.h>
#include <qmessagebox.h>
#include <qcheckbox.h>

ConfigDialog::ConfigDialog( QWidget * parent, const char * name, WFlags f)
	: QDialog(parent, name, TRUE, f)
{
	QFont combo_font("lcfont", 18);
	resize( QSize(400,140).expandedTo(minimumSizeHint()));

	setCaption(QString::fromUtf8("WPA設定"));
	setFont(QFont("lcfont", 20));

	QVBoxLayout *vbox = new QVBoxLayout(this);
	QGrid *grid = new QGrid(2, this);
	QLabel *label;

	grid->setSpacing(6);
	grid->setMargin(3);

	/* 接続名 */
	label = new QLabel(QString::fromUtf8("接続名:"),grid);
	label->setAlignment(AlignVCenter | AlignCenter);
	conn_name = new QLabel(grid);

	/* SSID */
	label = new QLabel(QString::fromUtf8("SSID:"),grid);
	label->setAlignment(AlignVCenter | AlignCenter);
	ssid = new QLineEdit(grid);
	ssid->setMaxLength(32);

	/* Stealth */
	label = new QLabel(QString::fromUtf8(""),grid);
	label->setAlignment(AlignVCenter | AlignCenter);
	stealth = new QCheckBox(QString::fromUtf8("ステルス SSID 対応"), grid);

	/* 暗号化 */
	label = new QLabel(QString::fromUtf8("暗号化:"),grid);
	label->setAlignment(AlignVCenter | AlignCenter);
	proto = new QComboBox(grid);
	proto->insertItem(QString::fromUtf8("None/WEP"));
	proto->insertItem(QString::fromUtf8("WPA/WPA2"));
	proto->setFont(combo_font);

	/* パスワード */
	label = new QLabel(QString::fromUtf8("Password:"),grid);
	label->setAlignment(AlignVCenter | AlignCenter);
	passwd = new QLineEdit("xxxxxxxxxx", grid);
	ssid->setMaxLength(64);
	passwd->setEchoMode(QLineEdit::Password);

	vbox->addWidget(grid);

	pass_change = false;

	connect( proto, SIGNAL(activated(int)),
			 this, SLOT(protoChanged(int)));
	connect( passwd, SIGNAL(textChanged(const QString &)),
			 this, SLOT(passChanged(const QString &)));
}

ConfigDialog::~ConfigDialog()
{
}

void ConfigDialog::protoChanged(int index)
{
	ConfFile::ProtoType ptype = (ConfFile::ProtoType) index;
	
	passwd->setDisabled(ptype == ConfFile::None_WEP);
	stealth->setDisabled(ptype == ConfFile::None_WEP);
}

void ConfigDialog::accept()
{
	conf->setSSID(ssid->text());
	conf->setStealthSSID(stealth->isChecked());

	switch(proto->currentItem()){
	case 0:
		conf->setProtocolType(ConfFile::None_WEP);
		break;
	case 1:
		conf->setProtocolType(ConfFile::WPA);

		if(pass_change){
			if(passwd->text().length() < 8 ||
			   passwd->text().length() > 63) {
				QMessageBox::critical(this, QString("Pass Phrase error!"),
									  QString::fromUtf8("パスワードは 8 文字以上 63 文字以下\nでなければなりません。"));
				return;
			}
			conf->setPassPhraseASCII(passwd->text());
		}
		break;
	}

	QDialog::accept();
}

void ConfigDialog::setConfFile(ConfFile *conf)
{
	ConfFile::ProtoType ptype;

	this->conf = conf;

	conn_name->setText(conf->getName());
	ssid->setText(conf->getSSID());

	ptype = conf->getProtocolType();
	proto->setCurrentItem(ptype != ConfFile::None_WEP);

	if(ptype != ConfFile::None_WEP){
		pass_change = false;
		passwd->setDisabled(false);
	}else{
		passwd->setDisabled(true);
	}

	stealth->setChecked(conf->getStealthSSID());
}

void ConfigDialog::passChanged(const QString &str)
{
	if(!pass_change){
		pass_change = true;
		passwd->setText("");
	}
}
