/*
  mainwindow.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of wpa_setting.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

//#define DEBUG

#include "mainwindow.h"

#include <qhgroupbox.h>
#include <qvbox.h>
#include <qhbox.h>
#include <qlistbox.h>
#include <qpushbutton.h>
#include <qcombobox.h>
#include <qlistview.h>
#include <qdir.h>

#include <stdio.h>
//#include "wificonnect.h"

#include <qdatetime.h>
#include <qlabel.h>

#include "configdialog.h"
#include "conffile.h"
#include "version.h"

MainWindow::MainWindow( QWidget *parent, const char *name, WFlags fl) :
	QHBox(parent, name, fl)
{
#ifndef QWS
	resize(640,640);
#endif

	setCaption(QString::fromUtf8("WPA 接続設定 - v") + WPA_SETTING_VER);

	QHBox *leftbox = new QHBox(this);
//	QHGroupBox *lgroup = new QHGroupBox(QString::fromUtf8("無線 LAN 接続一覧"), leftbox);
	QHBox *lgroup = new QHBox(leftbox);
	lgroup->setSpacing(3);
	setting_list = new QListView(lgroup);
	setting_list->addColumn(QString::fromUtf8("接続名"));
	setting_list->addColumn(QString::fromUtf8("SSID"));
	setting_list->addColumn(QString::fromUtf8("暗号化"));
	setting_list->addColumn(QString::fromUtf8(""), 0);
	setting_list->setAllColumnsShowFocus(true);

	QVBox *buttonbox = new QVBox(lgroup);
	QPushButton *config_button = new QPushButton(QString::fromUtf8("編集"), buttonbox);
//	QPushButton *connect_button = new QPushButton(QString::fromUtf8("接続"), buttonbox);
	QLabel *dummy = new QLabel(buttonbox);
	dummy->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding));

	connect( config_button, SIGNAL(pressed()),
			 this, SLOT(configPress()));
#if 0
	connect( connect_button, SIGNAL(pressed()),
			 this, SLOT(connectPress()));
#endif

	reloadItems();
}

MainWindow::~MainWindow()
{
}

void MainWindow::configPress(void)
{
	QListViewItem *item;

	item = setting_list->currentItem();

	ConfFile conf(item->text(3));
	if(!conf.isWlan())
		return;

	ConfigDialog dlg;

	dlg.setConfFile(&conf);

	if(dlg.exec() == QDialog::Accepted){
		conf.commitChanges();
		reloadItems();
	}
}

void MainWindow::connectPress(void)
{

}

void MainWindow::reloadItems()
{
	QDir dir("/home/zaurus/Applications/Network/modules/");
	QListViewItem *item;

	setting_list->clear();

	if(!dir.exists())
		return;

	dir.setFilter( QDir::Files | QDir::Readable );
	dir.setSorting( QDir::Name );

	const QFileInfoList *list = dir.entryInfoList();
	QFileInfoListIterator it(*list);
	QFileInfo *fi;

	while( (fi = it.current()) ){
		++it;
		ConfFile conf(fi->filePath());
		if(!conf.isWlan())
			continue;
		
		item = new QListViewItem(setting_list);

		item->setText(0, conf.getName());
		item->setText(1, conf.getSSID());
		item->setText(2, conf.getProtocolName());
		item->setText(3, fi->filePath());

		setting_list->insertItem(item);
	}
}
